from core import world
from core.agents import *
import random

import pygame

class Sky(Agent):
    def sortable(self):
        return 0


#151 is ground  110 is height
class Man(Agent):
    facing = 1
    speed = 1
    jumping = False
    jdir = -1
    landed = True
    def update(self,world):
        self.hotspot = [17,29]
        if self.facing == 1:
            self.load("art/man.png")
        elif self.facing == -1:
            self.load("art/man.png.flipped")
            self.pos[0]-=1
            if self.pos[0]<-20:
                self.delete()
        if self.jumping:
            self.pos[1]+=self.jdir*3.5
            if self.pos[1]<=84:
                self.pos[1]=84
                self.jdir = 1
            if self.pos[1]>=151:
                self.pos[1]=151
                self.jumping = False
    def jump(self):
        if not self.landed:
            return
        self.jdir = -1
        self.jumping = True
        self.landed = False
    def land(self):
        if self.pos[1]==151:
            self.landed = True
    def rect(self):
        return pygame.Rect([[self.pos[0]-20,self.pos[1]-32],[13,13]])

class Boulder(Agent):
    hotspot = [15,15]
    speed = 3
    def update(self,world):
        self.rot -= 2
        if self.rot<0:
            self.rot = 360
        self.pos[1]+=(self.speed-self.man.speed)/1.33
        self.pos[0]+=(self.speed-self.man.speed)
        if self.pos[1]>340:
            self.delete()
        if self.graphics:
            self.surface = pygame.transform.rotate(self.graphics,self.rot)
    def rect(self):
        return pygame.Rect([[self.pos[0]-10,self.pos[1]-10],[20,20]])
            
class Shrub(Agent):
    hotspot = [15,15]
    speed = 0
    def update(self,world):
        self.pos[1]-=self.man.speed+self.speed/1.43
        self.pos[0]-=(self.man.speed+self.speed)
        if self.pos[0]<-20:
            self.delete()
        if self.graphics:
            self.surface = pygame.transform.rotate(self.graphics,self.rot)
            
class BoulderdashWorld(world.World):
    def start(self):
        self.pos = 0
        self.next_boulder = 140
        self.next_fast_boulder = 1000
        self.next_shrub = 1
        self.bpos = 0
    def input(self,controller):
        self.man.speed = 1
        if pygame.key.get_pressed()[pygame.K_RIGHT]:
            self.man.speed = 2
        if pygame.key.get_pressed()[pygame.K_z]:
            self.man.jump()
        else:
            self.man.land()
        super(BoulderdashWorld,self).input(controller)
    def update(self):
        self.pos += self.man.speed
        self.bpos += 1
        bp = self.next_boulder-self.bpos
        fbp = self.next_fast_boulder-self.bpos
        sp = self.next_shrub-self.pos
        if bp<0:
            self.add_boulder(3)
            self.next_boulder = self.bpos+140
        if sp<0:
            self.add_shrub()
            self.next_shrub = self.pos+20
        if fbp<0:
            self.add_boulder(5)
            self.next_fast_boulder = self.bpos+300
        for o in self.objects:
            if isinstance(o,Boulder):
                if o.rect().colliderect(self.man.rect()):
                    self.replace(world.GameOverWorld(self.engine,["You are dead."]))
        super(BoulderdashWorld,self).update()
    def add_shrub(self):
        s = Shrub("core/boulderdash/shrub.png",[300,254])
        s.man = self.man
        s.speed = 1.5
        self.add(s)
        s = Shrub("core/boulderdash/shrub.png",[262,306])
        s.man = self.man
        s.speed = 4
        self.add(s)
    def add_boulder(self,spd=3):
        s = Boulder("core/boulderdash/boulder.png",[-84,-74])
        s.speed = spd
        s.man = self.man
        self.add(s)
        
def make_world(engine):
    """This makes the starting world"""
    w = BoulderdashWorld(engine)
    man = Man(pos=[191,151])
    w.man = man
    w.add(Agent("core/boulderdash/back.png"))
    w.add(man)
    w.add_shrub()
    return w
